cbo!() { /* proc-macro */ }Expand description
Create a CBOR slice out of the diagnostic notation (EDN) inside the given string.
This macro is useful for any EDN that does not happen to be compatible with Rust’s tokenization.
This is called cbo because it is most useful with r-strings:
use cbor_macro::cbo;
let parsed = cbo!(r#" ['CD', / Sad comment :-( / 123] "#);